;;; FG42 --- The mighty editor for the emacsians -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2020 Sameer Rahmani <lxsameer@gnu.org>
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://gitlab.com/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;;; Code:

;; Uncomment this line for debugging
;; (setq debug-on-error t)

(defvar global-font-size 11)

(use-flags
 (fg42/merge-with-default-flags
  wm
  dracula-theme
  -badwolf-theme
  python
  golang
  -vterm
  -smart-mode-line
  -mini-mode-line
  disable-modeline
  fg42/region-expansion-cube))


;;TODO: Move this block to a macro or something ===========
(when-wm
 (setq global-font-size 8)
 (custom-set-faces
  '(mini-modeline-mode-line
    ((((background light))
      :background "#aa0000" :height 0.1 :box nil)
     (t
      :background "#6272a4" :height 0.1 :box nil))))
 (fg42/wm-cube :number-of-workspaces 9)

 ;; Change the resolution and monitors to your need
 (defvar monitors
   '(:hdmi-only
     ("--output HDMI-A-0 --primary")))

 (require 'seq)
 (defun monitor-profiles ()
   (mapcar
    #'car
    (seq-partition monitors 2)))

 (defun monitor (mon)
   (interactive
    (list (completing-read
           "Monitor Profole: "
           (monitor-profiles))))

   (let ((cmd (mapconcat (lambda (x) (format "xrandr %s" x))
                         (plist-get monitors (intern (format "%s" mon)))
                         " && ")))
     (message "Setting monitor profile: %s" cmd)
     (async-shell-command cmd "*xrandr*")))

 (comment
   ;; how to run it via elisp
   (monitor :hdmi-only))

 (use-flags
  (fg42/merge-with-default-flags
   wm
   -python
   -golang
   rcirc
   vterm
   -company
   -projectile
   -lsp
   -flycheck
   fg42/region-expansion-cube)))

(fg42/editor
 :fg42/cursor-cube '(:type 'bar :color "#bd93f9")
 :fg42/font-cube '(:font-name "Fira code" :font-size global-font-size)
 :fg42/org-cube '(:global-tags '(("Math", ?m)
                                 ("Serene", ?s)
                                 ("FG42", ?f)
                                 ("Physics", ?p)
                                 ("Lab", ?l)
                                 ("Life", ?L))))

(when (file-exists-p "~/.fg42.user.el")
  (load "~/.fg42.user.el"))

(provide '.fg42)
;;; .fg42.el ends here
